@@ -10,8 +10,8 @@ try:
     # Change here if project is renamed and does not equal the package name
     dist_name = "bbox-utils"
     __version__ = version(dist_name)
-except PackageNotFoundError:
-    __version__ = "unknown"  # pragma: no cover
+except PackageNotFoundError:  # pragma: no cover
+    __version__ = "unknown"
 finally:
     del version, PackageNotFoundError
 
